aboutsummaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
Diffstat (limited to 'admin')
-rw-r--r--admin/include/functions.php2
-rw-r--r--admin/tags.php6
2 files changed, 4 insertions, 4 deletions
diff --git a/admin/include/functions.php b/admin/include/functions.php
index 47745a5a7..d84e66073 100644
--- a/admin/include/functions.php
+++ b/admin/include/functions.php
@@ -1756,7 +1756,7 @@ function tag_id_from_tag_name($tag_name)
$tag_name = mysql_escape_string($tag_name);
}
- // does the tag already exist?
+ // does the tag already exists?
$query = '
SELECT id
FROM '.TAGS_TABLE.'
diff --git a/admin/tags.php b/admin/tags.php
index 8f3ca5bee..21000de98 100644
--- a/admin/tags.php
+++ b/admin/tags.php
@@ -78,7 +78,7 @@ SELECT id, name
array_push(
$page['errors'],
sprintf(
- l10n('Tag "%s" already exist'),
+ l10n('Tag "%s" already exists'),
$tag_name
)
);
@@ -158,7 +158,7 @@ if (isset($_POST['add']) and !empty($_POST['add_tag']))
$tag_name = mysql_escape_string($_POST['add_tag']);
}
// does the tag already exist?
$query = '
SELECT id
FROM '.TAGS_TABLE.'
@@ -192,7 +192,7 @@ SELECT id
array_push(
$page['errors'],
sprintf(
- l10n('Tag "%s" already exist'),
+ l10n('Tag "%s" already exists'),
$tag_name
)
);
@@ -158,7 +158,7 @@ if (isset($_POST['add']) and !empty($_POST['add_tag']))
$tag_name = mysql_escape_string($_POST['add_tag']);
}
- // does the tag already exist?
+ // does the tag already exists?
$query = '
SELECT id